pub trait BitStoreMut: BitStore {
// Required methods
unsafe fn set(&mut self, index: u32);
unsafe fn unset(&mut self, index: u32);
fn union_with(&mut self, other: &Self);
fn intersect_with(&mut self, other: &Self);
fn difference_with(&mut self, other: &Self);
fn symmetric_difference_with(&mut self, other: &Self);
fn negate(&mut self);
}Expand description
A trait for types that can be used to store bits and can be modified.
Required Methods
Sourcefn union_with(&mut self, other: &Self)
fn union_with(&mut self, other: &Self)
Unions this bitset with another, modifying self in place.
Sourcefn intersect_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
Intersects this bitset with another, modifying self in place.
Sourcefn difference_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
Subtracts another bitset from this one, modifying self in place.
Sourcefn symmetric_difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
Subtracts this bitset from another one, modifying self in place.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl BitStoreMut for u8
impl BitStoreMut for u8
unsafe fn set(&mut self, index: u32)
unsafe fn unset(&mut self, index: u32)
fn union_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
fn negate(&mut self)
Sourceimpl BitStoreMut for u16
impl BitStoreMut for u16
unsafe fn set(&mut self, index: u32)
unsafe fn unset(&mut self, index: u32)
fn union_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
fn negate(&mut self)
Sourceimpl BitStoreMut for u32
impl BitStoreMut for u32
unsafe fn set(&mut self, index: u32)
unsafe fn unset(&mut self, index: u32)
fn union_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
fn negate(&mut self)
Sourceimpl BitStoreMut for u64
impl BitStoreMut for u64
unsafe fn set(&mut self, index: u32)
unsafe fn unset(&mut self, index: u32)
fn union_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
fn negate(&mut self)
Sourceimpl BitStoreMut for u128
impl BitStoreMut for u128
unsafe fn set(&mut self, index: u32)
unsafe fn unset(&mut self, index: u32)
fn union_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
fn negate(&mut self)
Sourceimpl BitStoreMut for usize
impl BitStoreMut for usize
unsafe fn set(&mut self, index: u32)
unsafe fn unset(&mut self, index: u32)
fn union_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
fn negate(&mut self)
Sourceimpl<'a, T: BitStoreMut> BitStoreMut for &'a mut T
impl<'a, T: BitStoreMut> BitStoreMut for &'a mut T
unsafe fn set(&mut self, index: u32)
unsafe fn unset(&mut self, index: u32)
fn union_with(&mut self, other: &Self)
fn intersect_with(&mut self, other: &Self)
fn difference_with(&mut self, other: &Self)
fn symmetric_difference_with(&mut self, other: &Self)
fn negate(&mut self)
Sourceimpl<T: BitStoreMut> BitStoreMut for Box<T>
Available on crate feature alloc only.
impl<T: BitStoreMut> BitStoreMut for Box<T>
Available on crate feature
alloc only.